/* --8<--8<--8<--8<--
 *
 * Copyright (C) 2006 Smithsonian Astrophysical Observatory
 *
 * This file is part of luasup
 *
 * luasup is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * luasup is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the 
 *       Free Software Foundation, Inc. 
 *       51 Franklin Street, Fifth Floor
 *       Boston, MA  02110-1301, USA
 *
 * -->8-->8-->8-->8-- */

#include <stddef.h>

#include "luasup.h"

/* must be in same order as SLuaArgType */
static const char *
type_name[] =
{
  "string",
  "number",
  "table",
  "nil",
  "function",
  "cfunction",
  "userdata"
};

#define NTYPES (sizeof( type_name ) / sizeof(const char *))

/*
  PROCEDURE
  slua_type_name - return a string containing the name of a type

  DESCRIPTION
  This routine returns a pointer to a character string identifying one
  of the Lua types.  If the type is not recognized, it returns @code{NULL}.

  The values of type that are supported are
  @code{SLua_STRING},
  @code{SLua_NUMBER},
  @code{SLua_TABLE},
  @code{SLua_NIL},
  @code{SLua_FUNCTION},
  @code{SLua_CFUNCTION},
  @code{SLua_USERDATA}
  .

  AUTHOR
  Diab Jerius

*/
  

const char *
slua_type_name( SLuaArgType type )
{
  if ( type < 0 || type >=  NTYPES )
    return NULL;

  return type_name[type];
}


/*
  PROCEDURE
  slua_type - return the type of a Lua object

  DESCRIPTION
  This routine returns the type (@code{SLuaArgType}) of a Lua object.
  of the Lua types.  If the type is not recognized, it returns
  @code{SLua_BOGUS}.

  AUTHOR
  Diab Jerius

*/
  

SLuaArgType
slua_type(
  lua_Object object	/* the object to test */
  )
{

  if ( lua_isnil      ( object ) ) return SLua_NIL;
  if ( lua_isnumber   ( object ) ) return SLua_NUMBER;
  if ( lua_isstring   ( object ) ) return SLua_STRING;
  if ( lua_istable    ( object ) ) return SLua_TABLE;
  if ( lua_isfunction ( object ) ) return SLua_FUNCTION;
  if ( lua_iscfunction( object ) ) return SLua_CFUNCTION;
  if ( lua_isuserdata ( object ) ) return SLua_USERDATA;

  return SLua_BOGUS;
}
